#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-04
# File  : cisco_meraki_appliance_performance.py (check plugin)


from _collections_abc import Mapping

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    register,
    check_levels,
    Service,
    render,
)
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import (
    CheckResult,
    DiscoveryResult,
    StringTable,
)
from cmk.base.plugins.agent_based.utils.cisco_meraki import (
    load_json,
)

# sample agent output
# {"perfScore": 1}
# sample string_table
# [['[{"perfScore": 0}]']]

def parse_appliance_performance(string_table: StringTable) -> int:
    json_data = load_json(string_table)
    if (json_data := json_data[0]) is None:
        return

    perfscore = json_data.get('perfScore')
    if isinstance(perfscore, int):
        return int(perfscore)


register.agent_section(
    name="cisco_meraki_org_appliance_performance",
    parse_function=parse_appliance_performance,
)


def discover_appliance_performance(section: int) -> DiscoveryResult:
    yield Service()


def check_appliance_performance(params: Mapping[str, any], section: int) -> CheckResult:
    yield from check_levels(
        value=section,
        label='Utilization',
        levels_upper=params.get('levels_upper'),
        render_func=render.percent,
        metric_name='utilization',
        boundaries=(0, 100),
    )


register.check_plugin(
    name='cisco_meraki_org_appliance_performance',
    service_name='Utilization',
    discovery_function=discover_appliance_performance,
    check_function=check_appliance_performance,
    check_default_parameters={
        'levels_upper': (60, 80),
    },
    check_ruleset_name='cisco_meraki_org_appliance_performance',
)
